import { useState } from "react";
import { Settings } from "../../lib/settings";
import NavBar from "../navigation/NavBar";
import LoginForm from "./LoginForm";
import { LogoutContext } from "../../lib/LogoutContext";
import { RefreshContext } from "../../lib/RefreshContext";
import TabView from "../TabView";

export default function AuthWrapper() {
  const [isConfigured, setIsConfigured] = useState(
    Boolean(Settings.getServiceUrl() && Settings.getAdminPassword()),
  );
  const [lastUpdate, setLastUpdate] = useState(Date.now());

  const handleLogout = () => {
    Settings.clearSettings();
    setIsConfigured(false);
  };

  const refresh = () => {
    setLastUpdate(Date.now());
  };

  if (!isConfigured) {
    return <LoginForm onLogin={() => setIsConfigured(true)} />;
  }

  return (
    <LogoutContext.Provider value={handleLogout}>
      <RefreshContext.Provider value={{ refresh, lastUpdate }}>
        <div className="min-h-screen flex flex-col">
          <NavBar />
          <div className="flex-1">
            <TabView />
          </div>
        </div>
      </RefreshContext.Provider>
    </LogoutContext.Provider>
  );
}
